c----------------------------------------------------------------------
      SUBROUTINE RSRTRL(nw,grpa2,itrjd,cnvcm,cnvvm,cnvlm,NDMMAX)
c----------------------------------------------------------------------
C   Calculate Spin scalar, transverse, longitudinal 
C   and trace of spin-vector response functions
c---------------------------------------------------------------------
c     Input
c       nw   : transferred energy number
c       itrjd   : transferred J
c       NDMMAX  :Maximum  number of the transition mode index, NDM 
c       grpa2(j,2,2,NDM): (pi/(4pi)^2)*Pi(j,l1,s1,l2,s2,q,w,NDtype)
c     OUTPUT
c       rps(w)     : spin scalar response function RS
c       rpv(w,NDM): trace of spin-vector response function RV
c       rpl(w,NDM) : spin longitudinal response function RL
c       cnvcm      : convergence check index for RS
c       cnvvm,    : convergence check index for RV
c----------------------------------------------------------------------
      include 'dimn.fh'
      include 'grpaj.fh'
      include 'rsrtrl.fh'
c
      complex   pis,piv(3),pil(3)
      real*8 cpi/3.141592654d0/
c
      j=itrjd+1
      fj=itrjd
      fjw1 = 2*itrjd+1.0
c
      cnvcm=0.0
      cnvvm=0.0
      cnvlm=0.0
C-----------------------------------------------------------------
C   Spin-scalar Response Function
      pis=2.0*fjw1*grpa2(j,1,1,1)
      rps(nw)=rps(nw)-(1.0/CPI)*aimag(pis)
c
      pisz=(1/CPI)*abs(aimag(pis))
      rsz =abs(rps(nw))
      cnvcz=0.0
      if(rsz.ne.0.0) cnvcz=pisz/rsz
      if(cnvcz.gt.cnvcm) cnvcm=cnvcz
C-----------------------------------------------------------------
      do 10 NDM=1,NDMMAX
c-----------------------------------------------------------------
C   Spin-vector response function
c-------------------------------------------------------------------- 
            piv(NDM)=2.0*(2.0*fj+1.0)*
     1           (grpa2(j,2,1,NDM)+grpa2(j,2,4,NDM)+grpa2(j,1,4,NDM))
            rpv(nw,NDM)=rpv(nw,NDM)-(1.0/CPI)*aimag(piv(NDM))
C
            pivz =(1.0/CPI)*abs(aimag(piv(NDM)))
            rvz  =abs(rpv(nw,NDM))
            cnvvz=0.0
            if(rvz.ne.0.0) cnvvz=pivz/rvz
            if(cnvvz.gt.cnvvm) cnvvm=cnvvz
C-----------------------------------------------------------------
C  Longitidinal response function 
         pil(NDM)=2.0*
     1        (fj*grpa2(j,2,1,NDM)
     2        -sqrt(fj*(fj+1.0))*(grpa2(j,2,2,NDM)
     3        +grpa2(j,2,3,NDM))
     4        +(fj+1.0)*grpa2(j,2,4,NDM))
         rpl(nw,NDM)=rpl(nw,NDM)-(1.0/CPI)*aimag(pil(NDM))
C-----------------------------------------------------------------
 10   continue
      return
      end
