c-------------------------------------------------------------------------
      subroutine sbessl(hx,bs,lmax01)
C-------------------------------------------------------------------------
C   Calculate the table of the spherical Bessel function j_l(x) (l=0-lmax)
C   Input 
C      hx     : x
C      lmax01 : lmax+1 (<= 100)
C   Output
C      bs(n)  : j_l(x) (n=l+1) 
c-------------------------------------------------------------------------
      implicit real*8 (a-h,o-z)
      real*4 hx,bs(100)
      dimension cj(100)
c
C Check for lmax
      if ((lmax01.le.0).or.(lmax01.gt.100)) then
        write(6,9000) lmax01
 9000   format(1x,'sbessl-stop. lmax01 is out of range. lmax01=',i3)
        stop
      end if
C
      x=hx
C
C For x=0
      if(x.le.0.0) then
        bs(1)=1.d0
        do 100 l=2,lmax01
  100     bs(l)=0.d0
        return
      end if
C
C Calculate j_0(x)
      if(x.gt.0.01d0) then
        fnorm=dsin(x)/x
      else
        fnorm=1.d0-x**2/6.d0+x**4/120.d0
      end if
      bs(1)=fnorm
      if(lmax01.eq.1) return
C
C For l>=1 
C   For  x <= 1.0
      if(x.le.1.d0) then
        anl=1.d0
        do 450 l=2,lmax01
          al2m2=l-1
          hal2=x/al2m2**2
          if(hal2.le.0.001d0) then
            bs(l)=0.0
          else
            anl=anl*(2.d0*al2m2+1.d0)
            al23=2.d0*al2m2+3.d0
            al25=al23*(2.d0*al2m2+5.d0)*2.d0
            al27=al25*(2.d0*al2m2+7.d0)*3.d0
            al29=al27*(2.d0*al2m2+9.d0)*4.d0
            h2=0.5d0*x*x
            h4=h2*h2
            h6=h4*h2
            h8=h4*h4
            hl2=x**al2m2
            bs(l)=hl2/anl*(1.d0-h2/al23+h4/al25-h6/al27+h8/al29)
          end if
  450   continue
        return
      end if
C
C  For x>1
      limit=min0(lmax01+30,100)
      limit2=limit-2
      cj(limit)=0.d0
      cj(limit-1)=1.d-25
      do 700 l=1,limit2
        lx=limit-l
  700 cj(lx-1)=dfloat(2*lx+1)/x*cj(lx)-cj(lx+1)
      cj0=3.d0/x*cj(1)-cj(2)
      coef=fnorm/cj0
      do 800 l=2,lmax01
        bs(l)=coef*cj(l-1)
  800 continue
      return
      end
